'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _fs = require('fs');

var _path = require('path');

var _flowRight = require('lodash/fp/flowRight');

var _flowRight2 = _interopRequireDefault(_flowRight);

var _identity = require('lodash/fp/identity');

var _identity2 = _interopRequireDefault(_identity);

var _isPlainObject = require('lodash/fp/isPlainObject');

var _isPlainObject2 = _interopRequireDefault(_isPlainObject);

var _webpackPartial = require('webpack-partial');

var _extractTextWebpackPlugin = require('extract-text-webpack-plugin');

var _extractTextWebpackPlugin2 = _interopRequireDefault(_extractTextWebpackPlugin);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var PRODUCTION = process.env.NODE_ENV === 'production';

var hasPostcssConfig = function hasPostcssConfig(root) {
  return (0, _fs.existsSync)(root + '/postcss.config.js') || (0, _fs.existsSync)(root + '/.postcssrc.json') || (0, _fs.existsSync)(root + '/.postcssrc.yml') || (0, _fs.existsSync)(root + '/.postcssrc.js') || (0, _fs.existsSync)(root + '/.postcssrc');
};

var getPostCSSOptions = function getPostCSSOptions(postcss, context) {
  if ((0, _isPlainObject2.default)(postcss)) {
    // The `postcss` option is an object. Pass it through as the
    // `postcss-loader` options.
    return postcss;
  }

  if (hasPostcssConfig(context)) {
    // There is a PostCSS config file at the project root. Return an empty
    // options object to allow the config to be used.
    return {};
  }

  if (hasPostcssConfig((0, _path.join)(context, 'config', 'postcss'))) {
    // There is a PostCSS config file in the `/config/postcss` directory.
    // Return an options object referencing it.
    return {
      config: (0, _path.join)(context, 'config', 'postcss')
    };
  }

  // Return an options object referencing the default PostCSS config that is
  // part of this config partial.
  return {
    config: __dirname
  };
};

/**
 * CSS Webpack loader partial.
 *
 * @param {Boolean|Object} options.extract Enable/disable Extract Text Plugin.
 * An object value is used as options for the Extract Text Plugin constructor.
 * @param {Boolean} options.minimize Enable/disable cssnano minification.
 * @param {Boolean} options.jsStyles Enable/disable `css-js-loader`.
 * @param {Boolean|Object} options.postcss Enable/disable `postcss-loader`.
 * An object value is used as options for `postcss-loader`.
 * @param {Boolean} options.modules Enable/disable CSS Modules.
 * @param {String} options.localIdentName CSS Modules local identifier template.
 * @returns {Function} Webpack config partial.
 */

exports.default = function () {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$extract = _ref.extract,
      extract = _ref$extract === undefined ? PRODUCTION : _ref$extract,
      _ref$minimize = _ref.minimize,
      minimize = _ref$minimize === undefined ? PRODUCTION : _ref$minimize,
      _ref$jsStyles = _ref.jsStyles,
      jsStyles = _ref$jsStyles === undefined ? true : _ref$jsStyles,
      _ref$postcss = _ref.postcss,
      postcss = _ref$postcss === undefined ? true : _ref$postcss,
      _ref$modules = _ref.modules,
      modules = _ref$modules === undefined ? true : _ref$modules,
      _ref$localIdentName = _ref.localIdentName,
      localIdentName = _ref$localIdentName === undefined ? PRODUCTION ? '[hash:base64]' : '[name]--[local]--[hash:base64:5]' : _ref$localIdentName,
      options = _objectWithoutProperties(_ref, ['extract', 'minimize', 'jsStyles', 'postcss', 'modules', 'localIdentName']);

  var IS_STYLE = jsStyles ? /\.(css(\.js)?|scss|styl|sass|less)$/ : /\.(css|scss|styl|sass|less)$/;
  var IS_JS_STYLE = /\.css\.js$/;

  var extractor = new _extractTextWebpackPlugin2.default(_extends({
    disable: !extract,
    filename: '[name].[contenthash].css'
  }, extract));

  var importLoaders = postcss ? 1 : 0;

  var query = _extends({ modules: modules, localIdentName: localIdentName, minimize: minimize, importLoaders: importLoaders }, options);

  return function (config) {
    return (0, _flowRight2.default)((0, _webpackPartial.plugin)(extractor), jsStyles ? (0, _webpackPartial.loader)({
      test: IS_JS_STYLE,
      loader: require.resolve('css-js-loader')
    }) : _identity2.default, postcss ? (0, _webpackPartial.loader)({
      test: IS_STYLE,
      loader: require.resolve('postcss-loader'),
      options: getPostCSSOptions(postcss, config.context)
    }) : _identity2.default, config.target === 'web' ? (0, _webpackPartial.loader)({
      test: IS_STYLE,
      loader: extractor.extract({
        use: {
          loader: require.resolve('css-loader'),
          query: query
        },
        fallback: require.resolve('style-loader')
      })
    }) : (0, _webpackPartial.loader)({
      test: IS_STYLE,
      loader: require.resolve('css-loader/locals'),
      query: query
    }))(config);
  };
};
//# sourceMappingURL=css.webpack.config.js.map